.. _2enota:

2enota
~~~~~~

2. Voor de toepassing van deze wet en de daarop berustende bepalingen wordt onder “ernstig 
   nadeel” verstaan, het bestaan van of het aanzienlijk risico op:  

a. levensgevaar, ernstig lichamelijk letsel, ernstige psychische, materiële, immateriële of 
   financiële schade, ernstige verwaarlozing of maatschappelijke teloorgang, ernstig verstoorde 
   ontwikkeling voor of vanbetrokkene of een ander; 
b. bedreiging van de veiligheid van betrokkene al dan niet doordat hij onder invloed van een 
   ander raakt; 
c. de situatie dat betrokkene met hinderlijk gedrag agressie van anderen oproept; 
d. de situatie dat de algemene veiligheid van personen of goederen in gevaar is. 


 HOOFDSTUK 3 CRITERIA VOOR EN DOELEN VAN VERPLICHTE ZORG  
 
Artikel 3:1 
 
1. Verplichte zorg is zorg die ondanks verzet als bedoeld in artikel 1:4 kan worden verleend op 
   grond van een: 

   a. zorgmachtiging; 
   b. crisismachtiging; 
   c. machtiging tot voortzetting van de crisismaatregel; 
   d. beslissing tot tijdelijke verplichte zorg voorafgaand aan een crisismaatregel als bedoeld in 
      artikel 7:3; 
   e. beslissing tot tijdelijke verplichte zorg in een noodsituatie als bedoeld in de artikelen 8:11 en 8:12. 

2. Verplichte zorg is tevens het in een accommodatie verrichten van onderzoek ter uitvoering van 
   een observatiemaatregel en het ontnemen van de vrijheid voorafgaand aan een 
   observatiemaatregel, bedoeld in artikel 7A:1, vierde lid. 
 
Artikel 3:2 
 
1. Zorg omvat de zorg van een zorgaanbieder jegens betrokkene die kan bestaan uit bestaat uit 
   bejegening, verzorging, verpleging, behandeling, begeleiding, bescherming, beveiliging, en 
   verplichte zorg als bedoeld in het tweede lid, die door een zorgaanbieder wordt verleend. 
2. Verplichte zorg bestaat uit het: 

a. toedienen van vocht, voeding en medicatie, alsmede het verrichten van medische controles of 
   andere medische handelingen en therapeutische maatregelen, ter behandeling van een psychische 
   stoornis, dan wel vanwege die stoornis, ter behandeling van een somatische aandoening;   
b. beperken van de bewegingsvrijheid;  
c. insluiten;  
d. uitoefenen van toezicht op betrokkene;  
e. onderzoeken aan kleding of lichaam;  
f. onderzoek van de woon- of verblijfsruimte op gedrag-beïnvloedende middelen en gevaarlijke voorwerpen; 
g. controleren op de aanwezigheid van gedrag beïnvloedende middelen; 
h. aanbrengen van beperkingen in de vrijheid het eigen leven in te richten, die tot gevolg hebben 
   dat betrokkene iets moet doen of nalaten, waaronder begrepen het beperken van het ontvangen 
   van bezoek of het gebruik van communicatiemiddelen; 
i. opnemen in een accommodatie; 
j. in een accommodatie uitvoeren van onderzoek ter uitvoering van een observatiemaatregel; 
k. ontnemen van de vrijheid van betrokkene door hem over te brengen naar een plaats die 
   geschikt is voor tijdelijk verblijf als bedoeld in artikel 7:3, derde lid, of artikel 7A:1, vierde lid. 

 
Artikel 3:3  
 

a. er geen mogelijkheden voor zorg op basis van vrijwilligheid zijn; 

a. een crisissituatie af te wenden, 

e. de geestelijke gezondheid van betrokkene dusdanig te herstellen dat hij zijn autonomie 

f. het stabiliseren of herstellen van de fysieke gezondheid van betrokkene in het geval diens 

c. het verlenen van verplichte zorg, gelet op het beoogde doel van verplichte zorg evenredig is; 

Indien het gedrag van een persoon als gevolg van zijn psychische stoornis, niet zijnde een 
psychogeriatrische aandoening of een verstandelijke handicap, leidt tot ernstig nadeel kan als 
uiterste middel verplichte zorg worden verleend, indien: 
 
b. er voor betrokkene geen minder bezwarende alternatieven met het beoogde effect zijn; 
 
en  

d. redelijkerwijs te verwachten is dat het verlenen van verplichte zorg effectief is. 
 
Artikel 3:4 
 
  Verplichte zorg kan worden verleend om: 
 
  b. ernstig nadeel af te wenden, 
  c. onderzoek naar de geestelijke gezondheid van betrokkene uit te voeren, 
  d. de geestelijke gezondheid van betrokkene te stabiliseren, zoveel mogelijk herwint, of gedrag als gevolg van zijn psychische stoornis leidt tot ernstig nadeel daarvoor. 
 
 
HOOFDSTUK 8 RECHTEN EN PLICHTEN BIJ DE TENUITVOERLEGGING EN UITVOERING 
            VAN DE CRISISMAATREGEL, OBSERVATIEMAATREGEL, MACHTIGING TOT 
            VOORTZETTING VAN DE CRISISMAATREGEL EN ZORGMACHTIGING. 
 
 
Artikel 8:7  
 
1. De zorgaanbieder is verplicht de zorg, genoemd in de crisismaatregel, de machtiging tot 
   voortzetting van de crisismaatregel of de zorgmachtiging, te verlenen. 
2. De zorgaanbieder is verplicht het onderzoek op grond van de observatiemaatregel te verlenen.  
3. De zorgaanbieder kan, naast de tijdelijke verplichte zorg voorafgaande aan de crisismaatregel, 
   bedoeld in artikel 7:3, alleen de vormen van verplichte zorg verlenen die zijn opgenomen in de 
   zorgmachtiging, de crisismaatregel, of een beslissing op grond van de artikelen 8:11 tot en met 8:14.  

3. Een zorgaanbieder verleent aan betrokkene slechts verplichte zorg als bedoeld in de 
   crisismaatregel, de machtiging tot voortzetting van de crisismaatregel of de zorgmachtiging tegen 
   overlegging van een afschrift van respectievelijk de crisismaatregel, de machtiging tot voortzetting 
   van de crisismaatregel of de zorgmachtiging.  
 

Strafrechtelijke handhaving 

g. 8:24 
h. 8:25 
i. 9:4 
j.  9:10, eerste lid, wat betreft overtreding van regels gesteld bij of krachtens de artikelen 8:24 en 8:25; 
k. 10:1; 
l. 13:1, derde, vierde en vijfde lid. 

